@@ -1,4 +1,4 @@
-# This program does some regression testing for package "gramEvol"
+# This program performs regression testing for package "gramEvol"
 
 # Author: Farzad Noorian <farzad.noorian@sydney.edu.au>
 
@@ -8,11 +8,11 @@
 ################################################################################
 library("gramEvol")
 
-bnfGrammarDef <- CreateGrammar("test.bnf", startSymb = '<expr>')			   
+bnfGrammarDef <- CreateGrammar("test.bnf", startSymb = '<expr>')
 stopifnot(GetGrammarNumOfExpressions(bnfGrammarDef) == 18500)
 
 genome = c(2, 1, 0, 0, 3, 3, 3, 1)
-expr = GrammarGenotypeToPhenotype(genome, bnfGrammarDef)
-stopifnot(expr$expr == "c1*v1/c2*v2")
+expr = GrammarMap(genome, bnfGrammarDef)
+stopifnot(as.character(expr) == "c1 * v1/c2 * v2")
 stopifnot(expr$type == "T")
 
