@@ -1,4 +1,4 @@
-# This program does some regression testing for package "gramEvol"
+# This program performs regression testing for package "gramEvol"
 
 # Author: Farzad Noorian <farzad.noorian@sydney.edu.au>
 
@@ -21,10 +21,10 @@ evalfunc <- function(l) {
 }
 
 x <- GeneticAlg.int(genomeLen = 20, codonMin = 0, codonMax = 20,
-                allowrepeat = FALSE, terminationFitness = -109,
+                allowrepeat = FALSE, terminationCost = -110,
                 monitorFunc = NULL, evalFunc = evalfunc)
 
-best.result <- x$bestChrom
+best.result <- x$best$genome
 
 stopifnot(sort(best.result[odd]) == 11:20)
 stopifnot(sort(best.result[even]) == 0:9)
